#!/usr/bin/env python
#-*- coding: utf-8 -*-

import logging
import requests
import ari

logging.basicConfig(level=logging.ERROR)
client = ari.connect('http://localhost:8088', 'asterisk', 'asterisk')

def safe_hangup(channel):
    """Safely hang up the specified channel"""
    try:
        channel.hangup()
        print "Hung up {}".format(channel.json.get('name'))
    except requests.HTTPError as e:
        if e.response.status_code != requests.codes.not_found:
            raise e

def safe_bridge_destroy(bridge):
    """Safely destroy the specified bridge"""
    try:
        bridge.destroy()
        print("safe_bridge_destroy")
    except requests.HTTPError as e:
        if e.response.status_code != requests.codes.not_found:
            raise e

def stasis_start_cb(channel_obj, ev):
    """Handler for StasisStart"""
    channel = channel_obj.get('channel')
    channel_name = channel.json.get('name')
    args = ev.get('args')

    if not args:
        print "Error: {} didn't provide any arguments!".format(channel_name)
        return

    if args and args[0] != 'incoming':
        # Only handle inbound channels here
        return

    if len(args) != 3:
        print "Error: {} didn't tell us who to dial".format(channel_name)
        channel.hangup()
        return

    print "Dial"
    outgoing = client.channels.create(endpoint="SIP/3000", app='ari-test', appArgs='outgoing', originator=channel)
    bridge = client.bridges.create(type='mixing')
    bridge.addChannel(channel=[channel.id, outgoing.id])
    outgoing.dial(caller=channel.id)

    def outgoing_start_cb(channel_obj, ev):
        # Clean up the bridge when done
        channel.on_event('StasisEnd', lambda *args: safe_bridge_destroy(bridge))

    def outgoing_dial_cb(channel, ev):
        #Dial handler for our dialed channel
        dialstatus = ev.get('dialstatus')
        print("dialstatus = [{}]".format(dialstatus))

    outgoing.on_event('StasisStart', outgoing_start_cb)
    outgoing.on_event('Dial', outgoing_dial_cb)

def stasis_end_cb(channel, event):
    print("<%s> has left the application" % channel.json.get('name'))

client.on_channel_event('StasisStart', stasis_start_cb)
client.on_channel_event('StasisEnd', stasis_end_cb)

client.run(apps='ari-test')
